require("ggplot2")
require("dplyr")

data <- read.csv("/Users/bouchard/w/blogobayes/www/ex/vax/results/all/Vaccines--1222259857/samples/allLogDensities.csv")

# ggplot has bad default sizes for large facetting
verticalSize <- 2.0 *  length(unique(data$chain)) 
horizontalSize <- 4.0

n_samples <- max(data$sample)
cut_off <- n_samples * 0.5
data <- subset(data, sample > cut_off)
hdi_upper <- function(samples) {
	n = length(samples)
	m = as.integer(0.9 * n)
	sorted_samples <- sort(samples)
  shortest_length <- Inf
  shortest_interval <- c()
  for (i in 1:(n-m)){
    lower <- sorted_samples[i]
    upper <- sorted_samples[i+m]
    interval_length <- upper - lower
    if (interval_length < shortest_length) {
      shortest_length <- interval_length
      shortest_interval <- c(lower, upper)
    }
  }
return (shortest_interval[2])
}
hdi_lower <- function(samples) {
	n = length(samples)
	m = as.integer(0.9 * n)
	sorted_samples <- sort(samples)
  shortest_length <- Inf
  shortest_interval <- c()
  for (i in 1:(n-m)){
    lower <- sorted_samples[i]
    upper <- sorted_samples[i+m]
    interval_length <- upper - lower
    if (interval_length < shortest_length) {
      shortest_length <- interval_length
      shortest_interval <- c(lower, upper)
    }
  }
return (shortest_interval[1])
}
hdi_df <- data %>% group_by(chain) %>%
 summarise(HDI.lower=hdi_lower(value),
           HDI.upper=hdi_upper(value))

p <- ggplot(data, aes(x = value)) +
  geom_density() + facet_grid(chain ~ .
  ) + 
  theme_bw() + 
  geom_segment(data = hdi_df, aes(x=HDI.lower, xend=HDI.upper, y=0, yend=0), col="red") + 
  xlab("allLogDensities") +
  ylab("density") +
  ggtitle("Density plot for: allLogDensities")
ggsave("/Users/bouchard/w/blogobayes/www/ex/vax/results/all/Vaccines--1222259857/posteriorPlots/allLogDensities.pdf", limitsize = F, height = verticalSize, width = horizontalSize)
